local moduleName = "player"

local L = AceLibrary('AceLocale-2.2'):new('SimpleUnitFrames_Player')

L:RegisterTranslations('enUS', function() return {

	["Player Frame"] = true,
	["Description"] = "Options for the player frame",
	["Middle Health Text"] = true,
	["Right Health Text"] = true,
	["Middle Mana Text"] = true,
	["Right Mana Text"] = true,
	["Middle Health Text Description"] = "Set middle health text to one of the formats",
	["Right Health Text Description"] = "Set right health text to one of the formats",
	["Middle Mana Text Description"] = "Set middle mana text to one of the formats",
	["Right Mana Text Description"] = "Set right health text to one of the formats",
	
} end)

L:RegisterTranslations('koKR', function() return {

	["Description"] = "플레이어 프레임에 대한 설정",
	
	["Middle Health Text"] = "중간 생명력 글자",
	["Right Health Text"] = "오른쪽 생명력 글자",
	["Middle Mana Text"] = "중간 마나 글자",
	["Right Mana Text"] = "오른쪽 마나 글자",
	["Middle Health Text Description"] = "중간 생명력 글자 표시 방법 선택",
	["Right Health Text Description"] = "오른쪽 생명력 글자 표시 방법 선택",
	["Middle Mana Text Description"] = "중간 마나 글자 표시 방법 선택",
	["Right Mana Text Description"] = "오른쪽 마나 글자 표시 방법 선택",
	
} end)

local Player = SimpleUnitFrames:NewModule(moduleName, "AceEvent-2.0")

Player.core.defaults[moduleName] = {
	mhp = "currmaxhp",
	rhp = "percenthp",
	mmp = "currmaxmp",
	rmp = "percentmp",
}

local OPTION_ORDER = 100
Player.consoleOptions = {
	type = 'group',
	name = L['Player Frame'],
	desc = L['Description'],
	args = {	
		mhp = {
			order = OPTION_ORDER + 1,
			type = 'text',
			name = L['Middle Health Text'],
			desc = L['Middle Health Text Description'],
			get = function() return Player.db.mhp end,
			set = function(v) 
							Player.db.mhp = v
							Player:UpdateHealth()
						end,
			validate = Player.core.formatList,
		},
		rhp = {
			order = OPTION_ORDER + 2,
			type = 'text',
			name = L['Right Health Text'],
			desc = L['Right Health Text Description'],
			get = function() return Player.db.rhp end,
			set = function(v) 
							Player.db.rhp = v
							Player:UpdateHealth()
						end,
			validate = Player.core.formatList,
		},
		mmp = {
			order = OPTION_ORDER + 3,
			type = 'text',
			name = L['Middle Mana Text'],
			desc = L['Middle Mana Text Description'],
			get = function() return Player.db.mmp end,
			set = function(v)
							Player.db.mmp = v
							Player:UpdateMana()
						end,
			validate = Player.core.formatList,
		},
		rmp = {
			order = OPTION_ORDER + 4,
			type = 'text',
			name = L['Right Mana Text'],
			desc = L['Right Mana Text Description'],
			get = function() return Player.db.rmp end,
			set = function(v)
							Player.db.rmp = v
							Player:UpdateMana()
						end,
			validate = Player.core.formatList,
		},
		
	}
}

function Player:OnInitialize()

	
	-- Disable the default player HP/MP text.
	hooksecurefunc(PlayerFrameHealthBar.TextString, "Show", self.Show)
	hooksecurefunc(PlayerFrameManaBar.TextString, "Show", self.Show)
	
end

function Player:OnEnable()
	self:RegisterEvent("UNIT_HEALTH", "OnHealthChange")
	self:RegisterEvent("UNIT_MAXHEALTH", "OnHealthChange")

	self:RegisterEvent("UNIT_MANA", "OnManaChange")
	self:RegisterEvent("UNIT_MAXMANA", "OnManaChange")

	self:RegisterEvent("UNIT_RAGE", "OnManaChange")
	self:RegisterEvent("UNIT_MAXRAGE", "OnManaChange")

	self:RegisterEvent("UNIT_ENERGY", "OnManaChange")
	self:RegisterEvent("UNIT_MAXENERGY", "OnManaChange")

	self:RegisterEvent("UNIT_DISPLAYPOWER", "OnManaChange")

	self:Refresh()	
end

function Player:Refresh()
	self:UpdateHealth()
	self:UpdateMana()
end

-- The hook: Hide() on Show()!
function Player.Show(textString)
	textString:Hide()
end


function Player:OnHealthChange(arg1)
	if arg1 == 'player' then
		self:UpdateHealth()
	end
end

function Player:OnManaChange(arg1)
	if arg1 == 'player' then
		self:UpdateMana()
	end
end


function Player:UpdateHealth()
	SUF_HealthMiddleText:SetText( self:GetValueText('player', self.db.mhp ) )
	SUF_HealthRightText:SetText( self:GetValueText('player', self.db.rhp ) )	
end

function Player:UpdateMana()
	SUF_ManaMiddleText:SetText( self:GetValueText('player', self.db.mmp ) )
	SUF_ManaRightText:SetText( self:GetValueText('player', self.db.rmp ) )	
end
